==> haskell-stateref-0.3-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stateref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stateref
version:              0.3
visibility:           public
id:                   stateref-0.3-9FDc21sfqvnDNL9Z80msqK
key:                  stateref-0.3-9FDc21sfqvnDNL9Z80msqK
license:              LicenseRef-PublicDomain
maintainer:           James Cook <mokus@deepbondi.net>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             http://code.haskell.org/~mokus/stateref/
synopsis:             Abstraction for things that work like IORef.
description:
    A collection of type-classes generalizing the
    read\/write\/modify operations for stateful variables
    provided by things like IORef, TVar, &c.
    Note that The interface has changed a bit from the
    0.2.* version.  \"*Ref\" functions are now called
    \"*Reference\" and new \"*Ref\" function exist with
    simpler signatures.
    The new '\''Ref'\'' existential type provides a convenient
    monad-indexed reference type, and the HasRef class
    indicates monads for which there is a default
    reference type for every referent.

category:             Data
abi:                  12eb7f40637dbf46ebc868cf34321f8e
exposed:              True
exposed-modules:
    Data.Accessor Data.MRef Data.MRef.Instances Data.MRef.Types
    Data.StateRef Data.StateRef.Instances Data.StateRef.Types

hidden-modules:
    Data.StateRef.Instances.Undecidable Data.StateRef.Instances.STM
    Data.MRef.Instances.STM

import-dirs:          /usr/lib/ghc-9.2.8/site-local/stateref-0.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/stateref-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stateref
hs-libraries:         HSstateref-0.3-9FDc21sfqvnDNL9Z80msqK
depends:              base-4.16.4.0 mtl-2.2.2 stm-2.5.0.2
haddock-interfaces:   /usr/share/doc/haskell-stateref/html/stateref.haddock
haddock-html:         /usr/share/doc/haskell-stateref/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stateref-0.3-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stateref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stateref
version:              0.3
visibility:           public
id:                   stateref-0.3-9u8dXq0kJf7qLN0hkKSzn
key:                  stateref-0.3-9u8dXq0kJf7qLN0hkKSzn
license:              LicenseRef-PublicDomain
maintainer:           James Cook <mokus@deepbondi.net>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             http://code.haskell.org/~mokus/stateref/
synopsis:             Abstraction for things that work like IORef.
description:
    A collection of type-classes generalizing the
    read\/write\/modify operations for stateful variables
    provided by things like IORef, TVar, &c.
    Note that The interface has changed a bit from the
    0.2.* version.  \"*Ref\" functions are now called
    \"*Reference\" and new \"*Ref\" function exist with
    simpler signatures.
    The new '\''Ref'\'' existential type provides a convenient
    monad-indexed reference type, and the HasRef class
    indicates monads for which there is a default
    reference type for every referent.

category:             Data
abi:                  c6e3a2f035f7e528479b9ccf91f0978f
exposed:              True
exposed-modules:
    Data.Accessor Data.MRef Data.MRef.Instances Data.MRef.Types
    Data.StateRef Data.StateRef.Instances Data.StateRef.Types

hidden-modules:
    Data.StateRef.Instances.Undecidable Data.StateRef.Instances.STM
    Data.MRef.Instances.STM

import-dirs:          /usr/lib/ghc-9.4.8/site-local/stateref-0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/stateref-0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/stateref-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stateref
hs-libraries:         HSstateref-0.3-9u8dXq0kJf7qLN0hkKSzn
depends:              base-4.17.2.1 mtl-2.2.2 stm-2.5.1.0
haddock-interfaces:   /usr/share/doc/haskell-stateref/html/stateref.haddock
haddock-html:         /usr/share/doc/haskell-stateref/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
